<?php
// app/Controllers/EventController.php

ob_start();
require_once(__DIR__ . '/../Models/Event.php');
require_once(__DIR__ . '/TicketController.php');


class EventController {
    private $eventModel;

    public function __construct() {
        $this->eventModel = new EventModel();
    }

    public function createEvent($event_name, $stock, $event_price, $event_date, $event_location, $gambar, $vid){
        $success = $this->eventModel->createEvent($event_name, $stock, $event_price, $event_date, $event_location, $gambar, $vid);

        if ($success) {
            $ticketController = new TicketController();
            $event_id = $this->eventModel->getLastEventId();
            for ($i = 0; $i < $stock; $i++) {
                $ticketController->createTicket($event_name . " Ticket", $event_id);
            }
        }
        return $success;
    }

    public function getEvent($eventId) {
        return $this->eventModel->getEvent($eventId);
    }

    public function updateEvent($eventId, $event_name, $event_price, $event_date, $event_location, $gambar, $vid){
        $eventModel = new EventModel();
        $eventModel->updateEvent($eventId, $event_name, $event_price, $event_date, $event_location, $gambar, $vid);
        
        $ticketController = new TicketController();
        $ticketController->updateTicketbyEventId($eventId, $event_name . " Ticket");
    }

    public function deleteEvent($eventId) {
        return $this->eventModel->deleteEvent($eventId);
    }

    public function getAllEvents() {
        return $this->eventModel->getAllEvents();
    }

    public function paginateEvents($events = [], $page = 1, $pagesize = 10) {
        $totalEvents = count($events);
        $maxpage = ceil($totalEvents / $pagesize);
        if ($page > $maxpage) {
            $page = $maxpage;
        }
        $offset = $pagesize * ($page - 1);
        $selectedEvents = array_slice($events, $offset, $pagesize);
    
        return [
            'events' => $selectedEvents,
            'total' => $totalEvents,
            'page' => $page,
            'maxpage' => $maxpage,
        ];
    }
    


    public function searchEvents($searchQuery, $sortKey, $minStock = null) {
        try {
            return $this->eventModel->searchEvents($searchQuery, $sortKey, $minStock);
        } catch (Exception $e) {
            echo "Error searching events: " . $e->getMessage();
            return [];
        }
    }

    public function handleRequest() {
        if (isset($_POST['eventAction'])) {
            if ($_POST['eventAction'] === 'createEvent') {
                unset($_POST['eventAction']);
                $eventName = $_POST['eventName'];
                $eventStock = $_POST['eventStock'];
                $eventPrice = $_POST['eventPrice'];
                $eventDate = $_POST['eventDate'];
                $eventLocation = $_POST['eventLocation'];

                $imageFilePath = isset($_FILES['gambar']) && $_FILES['gambar']['error'] === 0 ? $_FILES['gambar'] : null; 
                $vidFilePath = isset($_FILES['vid']) && $_FILES['vid']['error'] === 0 ? $_FILES['vid'] : null;

                $success = $this->createEvent($eventName, $eventStock, $eventPrice, $eventDate, $eventLocation, $imageFilePath, $vidFilePath);
                if($success){
                    header("Location:Views/home/home.php");
                    ob_end_flush();
                } else {
                    header("Location:Views/event/create.php");
                    ob_end_flush();
                }
            }
            elseif ($_POST['eventAction'] === 'updateEvent') {
                unset($_POST['eventAction']);
                $eventId = $_POST['eventId'];
                $eventName = $_POST['eventName'];
                $eventPrice = $_POST['eventPrice'];
                $eventDate = $_POST['eventDate'];
                $eventLocation = $_POST['eventLocation'];

                $imageFilePath = isset($_FILES['gambar']) && $_FILES['gambar']['error'] === 0 ? $_FILES['gambar'] : null; 
                $vidFilePath = isset($_FILES['vid']) && $_FILES['vid']['error'] === 0 ? $_FILES['vid'] : null;

                $this->updateEvent($eventId, $eventName, $eventPrice, $eventDate, $eventLocation, $imageFilePath, $vidFilePath);
                header("Location:Views/home/home.php");
                ob_end_flush();
            }
            elseif ($_POST['eventAction'] === 'deleteEvent') {
                unset($_POST['eventAction']);
                $eventId = $_POST['eventId'];
                $this->deleteEvent($eventId);
                header("Location:Views/home/home.php");
                ob_end_flush();
            }
        } else {
            // other
        }
        if (isset($_GET['eventAction'])) {
            if ($_GET['eventAction'] === 'getEvent') {
                $eventId = $_GET['eventId'];
                unset($_GET['eventAction']);
                unset($_GET['eventId']);
                echo json_encode($this->getEvent($eventId));
            } else {
                // other
            }
        }
    }

}
?>
