<?php
    session_start();
    ob_start();
    if (!isset($_SESSION["user_id"])) {
        echo "here";
        // User is not authenticated; redirect to login page
        header("Location: /app/Views/login/login.php");
        ob_end_flush();
    }

    require_once '../../Controllers/PembelianController.php';
    require_once '../../Controllers/TicketController.php';
    require_once '../../Controllers/UserController.php';
    require_once '../../Controllers/EventController.php';

    $eventController = new EventController();
    $pembelianController = new PembelianController();
    $ticketController = new TicketController();
    $userController = new UserController();

    // Handle search query
    $searchQuery = isset($_GET['search']) ? $_GET['search'] : '';
    $sortKey = isset($_GET['sort']) ? $_GET['sort'] : 'name'; 
    $minStock = isset($_GET['min_stock']) ? $_GET['min_stock'] : null;
    
    // Get search results or all events 
    $searchResults = $eventController->searchEvents($searchQuery, $sortKey, $minStock);
    if (!isset($_GET['page'])) {
        $_GET['page'] = 1;
    }
    $paginationData = $eventController->paginateEvents($searchResults,$_GET['page']);
    $events = $paginationData['events'];
    $totalEvents = $paginationData['total'];
    $currentPage = $paginationData['page'];
    $maxPage = $paginationData['maxpage'];

    $isAdmin = $userController->getUser($_SESSION['user_id'])['isAdmin'];
?>

<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>HOME • TICKET KU</title>
    <link rel="stylesheet" type="text/css" href="/../../styles/global.css">
    <link rel="stylesheet" type="text/css" href="/../../styles/form.css">
    <link rel="stylesheet" type="text/css" href="/../../styles/footer.css">
    <link rel="stylesheet" type="text/css" href="/../../styles/navbar.css">
    <link rel="stylesheet" type="text/css" href="/../../styles/container.css">
    <link rel="stylesheet" type="text/css" href="/../../styles/auth.css">
    <link rel="stylesheet" type="text/css" href="/../../styles/dropdown.css">
    <link rel="stylesheet" type="text/css" href="/../../styles/pagination.css">
    <link rel="stylesheet" type="text/css" href="/../../styles/media.css">
</head>

<body>
<!-- Navbar -->
    <?php include '../template/navbar.php';?>

    <div class="main-content">
        <div class="column">
            <?php if ($isAdmin) : ?>
                <button onclick="openCreateEventPage()" id="createEventBtn" class="admin">Create Event</button>
            <?php endif; ?>
            <div class="row">
                <input type="text" id="searchInput" placeholder="Search.." value="<?= htmlspecialchars($searchQuery)?>" style="width:250%;">
                <select name="sort" id="sortSelect" class="styled-select">
                    <option value="" <?= empty($sortKey) ? 'selected' : '' ?>>No Sorting</option>
                    <option value="name" <?= $sortKey === 'name' ? 'selected' : '' ?>>Sort by Name</option>
                    <option value="location" <?= $sortKey === 'location' ? 'selected' : '' ?>>Sort by Location</option>
                </select>
                <!-- Change input type to "text" for minimum stock -->
                <input type="text" id="minStockInput" name="min_stock" placeholder="Min Stock" value="<?= htmlspecialchars($minStock) ?>">
                <button type="submit" id="search-button">Search</button>
            </div>
            
            <?php foreach ($events as $event) :    
                include '../template/event.php';
            endforeach;?>

            <div class="pagination">
                <?php if ($currentPage > 1) : ?>
                    <a href="?page=<?= $currentPage - 1 ?>">Previous</a>
                <?php endif; ?>
                
                <?php for ($i = 1; $i <= $maxPage; $i++) : ?>
                    <a href="?page=<?= $i ?>" <?= ($i == $currentPage) ? 'class="active"' : '' ?>><?= $i ?></a>
                <?php endfor; ?>
        
                <?php if ($currentPage < $maxPage) : ?>
                    <a href="?page=<?= $currentPage + 1 ?>">Next</a>
                <?php endif; ?>
            </div>
        </div>
    </div>
    
    <?php include '../template/footer.php';?>

    <script defer>
        function toggleMenu() {
            const navbar = document.querySelector('.navbar ul');
            navbar.classList.toggle('show');
        }

        function openCreateEventPage() {
            window.location.href = "/app/Views/event/create.php";
        }

        let debounceTimer;
        let searchInput = document.getElementById('searchInput');
        let cursorPosition = 0;

        // Initialize the cursor position
        searchInput.addEventListener('input', function () {
            cursorPosition = this.selectionStart;
        });

        function debounceSearch() {
            clearTimeout(debounceTimer);
            debounceTimer = setTimeout(function () {
                // Get the search input values
                const searchQuery = searchInput.value;
                const minStock = document.getElementById('minStockInput').value;
                const sortKey = document.getElementById('sortSelect').value;

                // Construct the URL with search, min_stock, and sort parameters
                const url = `/app/Views/home/home.php?search=${encodeURIComponent(searchQuery)}&min_stock=${encodeURIComponent(minStock)}&sort=${encodeURIComponent(sortKey)}`;

                // Redirect to the updated URL
                window.location.href = url;

                // Restore focus and cursor position
                searchInput.focus();
                searchInput.setSelectionRange(cursorPosition, cursorPosition);
            }, 500); // Adjust the debounce delay as needed (in milliseconds)
        }

        // Attach the debounce function to the search input's input event
        searchInput.addEventListener('input', debounceSearch);
        document.getElementById('minStockInput').addEventListener('input', debounceSearch);
        // Attach an event listener to the sort dropdown
        document.getElementById('sortSelect').addEventListener('change', function () {
            // Trigger the debounceSearch function when the sorting option changes
            debounceSearch();
        });

        // Function to show delete confirmation dialog
        function showConfirmationDialog(eventId) {
            if (confirm("Are you sure you want to delete this event?")) {
                // If the user confirms, submit the corresponding form
                document.getElementById("deleteEventForm" + eventId).submit();
            }
        }

        // Attach the confirmation dialog to all buttons with the class "confirmDeleteBtn"
        const deleteButtons = document.querySelectorAll(".confirmDeleteBtn");
        deleteButtons.forEach(button => {
            button.addEventListener("click", function() {
                const eventId = this.getAttribute("data-eventid");
                showConfirmationDialog(eventId);
            });
        });
    </script>

</body>

</html>
